package de.hawhamburg.reachability.ui.frame.simulation.resource;

import de.hawhamburg.reachability.ui.enumeration.FieldType;

/**
 * Data object which represents a simulation parameter for display within a start simulation user interface.<br><br>
 * 
 * Objects of this class are each representing a single parameter within a start simulation user interface. They provide
 * other display names, default values and field types to simplify the rendering process.
 *
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR}
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class SimulationParameter {
    
    /**
     * The parameters name as {@link String}.
     */
    private String name;
    
    /**
     * The text as {@link String} that shall be displayed as name to the user.
     */
    private String display;
    
    /**
     * The {@link FieldType} which describes, how the formula field of this parameter shall be rendered.
     */
    private FieldType fieldType;
    
    /**
     * The default value of this parameter as {@link String}.
     */
    private String defaultValue;
    
    /**
     * Initializes a new {@link SimulationParameter} object.
     *
     * @param nameIn            The parameters name as {@link String}.
     * @param displayIn         The text as {@link String} that shall be displayed as name to the user.
     * @param fieldTypeIn       The {@link FieldType} which describes how the formula field for this parameter shall be 
     *                          rendered.
     * @param defaultValueIn    The default value of this parameter as {@link String}.
     */
    public SimulationParameter(final String nameIn,
                               final String displayIn,
                               final FieldType fieldTypeIn,
                               final String defaultValueIn) {
        this.name           = nameIn;
        this.display        = displayIn;
        this.fieldType      = fieldTypeIn;
        this.defaultValue   = defaultValueIn;
    }
    
    /**
     * Returns the parameters name as {@link String}.
     * 
     * @return                  The parameters name as {@link String}.
     */
    public final String getName() {
        return name;
    }
    
    /**
     * Returns the parameters display name as {@link String}.
     * 
     * @return                  The parameters display name as {@link String}.
     */
    public final String getDisplay() {
        return display;
    }
    
    /**
     * Returns the parameters field type as {@link FieldType}.
     * 
     * @return                  The parameters field type as {@link FieldType}.
     */
    public final FieldType getFieldType() {
        return fieldType;
    }
    
    /**
     * Returns the parameters default value as {@link String}.
     * 
     * @return                  The parameters default name as {@link String}.
     */
    public final String getDefaultValue() {
        return defaultValue;
    }
}
