package de.hawhamburg.reachability.json;

import de.hawhamburg.lifecycle.data.JsonLPObject;
import de.hawhamburg.reachability.enumeration.ReachabilityGroup;
import de.hawhamburg.reachability.enumeration.ReachabilityStatus;

/**
 * Basic reachability instruction message to give active feedback to the reachability agent.<br><br>
 * 
 * This class represents the structure of the JSON messages which describes a reachability instruction for this 
 * reachability agent. This messages are incoming messages and shall be interpreted by the reasoner of this agent. This 
 * message is designed to transport the users feedback. If e.g. the user doesn't agree with the reasoners choice of 
 * reachability state, he will be able to inform the reasoner about this lack by using this message and send it from a
 * user interface.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class JsonReachabilityInstruction extends JsonLPObject {

    /**
     * The group for which the feedback is specified.
     */
    public ReachabilityGroup Group;
    
    /**
     * The correct state of reachability related to the users opinion/choice.
     */
    public ReachabilityStatus Status;
    
    /**
     * Some textual remark (not further specified in this version).
     */
    public String Remark;
    
    /**
     * Public default constructor to create a new instance of this class.
     */
    public JsonReachabilityInstruction() { }
}
